find_bg_image

Function find_bg_image 

pub fn find_bg_image(
    project_dir: &Path,
    name: &str,
) -> Result<(PathBuf, PctType)>
Find an image path for BG loading.

Original Siglus logic:

  1. Search append directories from the current append entry, in order.
  2. In each directory, search g00/ first.
  3. If not found, search bg/.
  4. For each directory, extension order is: g00, bmp, png, jpg, dds.

If name already contains an extension, we only test that extension.