pub fn find_bg_image(
project_dir: &Path,
name: &str,
) -> Result<(PathBuf, PctType)>Expand description
Find an image path for BG loading.
Original Siglus logic:
- Search append directories from the current append entry, in order.
- In each directory, search
g00/first. - If not found, search
bg/. - For each directory, extension order is: g00, bmp, png, jpg, dds.
If name already contains an extension, we only test that extension.